<?php
/*
Plugin Name: Copyright
Plugin URI: http://www.symbolcraft.com/software/wordpress/copyright/
Description: Insures each page copyright date range includes the first date of publication as well as the current date.
Author: Paton J. Lewis
Version: 1.1
Author URI: http://www.symbolcraft.com
*/

/*
LICENSE

Copyright 2007 Paton J. Lewis <pjl@symbolcraft.com>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.	 See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place, Suite 330, Boston, MA 02111-1307 USA
*/

/*
Contributors:
-------------
Original author: Paton J. Lewis <pjl@symbolcraft.com>
Testing on WordPress 2.1.2: Harri Nyman <hn@hn.cx>
Initial Italian localization: Paton J. Lewis <pjl@symbolcraft.com>
*/

// Initialize this plugin (called by 'init' hook installed below):
function pjlCopyrightInit()
	{
	load_plugin_textdomain( 'copyright', 'wp-content/plugins' );
	}

// The add_action call at the end of this file adds the following function
// to the 'admin_menu' hook:
function pjlCopyrightAddAdminPage()
	{
	add_options_page( __( 'Copyright', 'copyright' ),
										__( 'Copyright', 'copyright' ),
										7, __FILE__, 'pjlCopyrightAdmin' );
	}

// Return the default settings for the Copyright plugin:
function pjlCopyrightGetDefaultOptions()
	{
	return array( 'pattern' => __( 'Copyright &copy; [date] [blog]', 'copyright' ) );
	}

// Get the Copyright plugin options from the site database, filling in with
// default values if they're not set yet:
function pjlCopyrightGetOptions()
	{
	$options = get_settings( 'pjlCopyrightPluginOptions' );
	if( !$options )
		{
		$options = pjlCopyrightGetDefaultOptions();
		update_option( 'pjlCopyrightPluginOptions', $options );
		}
	return $options;
	}

// Handles the plugin settings page:
function pjlCopyrightAdmin()
	{
	if( $_POST['updateCopyrightOptions'] )
		{
		$options = array( 'pattern' => $_POST['pattern'] );
		update_option( 'pjlCopyrightPluginOptions', $options );
		echo '<div class="updated"><p><strong>' .
			__( 'Options saved.', 'copyright' ) .
			'</strong></p></div>';
		}
	else
		$options = pjlCopyrightGetOptions();
	$defaultOptions = pjlCopyrightGetDefaultOptions();
	echo '<div class="wrap">
<h2>' . __( 'Copyright Plugin 1.1 Options', 'copyright' ) . '</h2>
<script language="JavaScript">
function pjlCopyrightSetDefaults( form )
{
form.pattern.value = "' . $defaultOptions['pattern'] . '";
}
</script>
<form method="post">
<input type="hidden" name="updateCopyrightOptions" value="1"/>
<p>' . __( 'Copyright String', 'copyright' ) . ': 
<input type="text" name="pattern" size="60" value="' . htmlentities( $options['pattern'] ) . '"/>
<input type="button" value="'. __( 'Load Default', 'copyright' ) . '" onClick="pjlCopyrightSetDefaults(this.form)"/>
<p>' . __( 'You may enter HTML character entities, such as <b><code>&amp;copy;</code></b> for "&copy;".' , 'copyright' ) . '
<p>' . __( 'In addition, two optional variables are supported:', 'copyright' ) . '</p>
<ul>
<li><b>[date]</b> ' . __( 'if present is replaced with the date range, and', 'copyright' ) . '
<li><b>[blog]</b> ' . __( 'if present is replaced with the blog name', 'copyright' ) . '.
</ul>
<p><i>' . sprintf( __( 'For documentation and updates, please see this plugin\'s %shomepage%s.', 'copyright' ),
'<a href="http://www.symbolcraft.com/software/wordpress/copyright/">', '</a>' ) . '</i></p>
<p class="submit"><input type="submit" value="' . __( 'Update Options', 'copyright' ) . '"/></p>
</form>
</div>';
	}

// The following function can be called within a post loop to insure that
// an index page contains a copyright date that includes the earliest post
// in a list of posts.
function pjlCopyrightMin()
	{
	global $page_copyright_start_date;
	$post_date = get_post_time( "Y" );
	if( !isset( $page_copyright_start_date ) ||
			$page_copyright_start_date > $post_date )
		$page_copyright_start_date = $post_date;
	}

// This function returns a string containing the copyright formatted as
// specified in the option panel. If the variable $page_copyright_start_date
// is set within the page that's being processed, then that start date is
// used. This is useful for static pages that are external to WordPress. If
// $page_copyright_start_date is not set, then the post publication date is
// used. This works for static pages within WordPress as well as regular
// posts. The date range also always includes the current year.
function pjlCopyrightGet()
	{
	global $page_copyright_start_date;
	if( !isset( $page_copyright_start_date ) )
		$page_copyright_start_date = get_post_time( "Y" );
	$date_range_str = $page_copyright_start_date;
	if( $page_copyright_start_date != date( "Y" ) )
		$date_range_str .= "-" . date( "Y" );
	$options = pjlCopyrightGetOptions();
	// PHP prior to 4.3.3 has a bug with array parameters to str_replace,
	// so to be safe we need to call str_replace twice:
	$tmp = str_replace( '[date]', $date_range_str, $options[ 'pattern' ] );
	return str_replace( '[blog]', get_bloginfo( 'name' ), $tmp );
	}

add_action( 'init', 'pjlCopyrightInit' );
add_action( 'admin_menu', 'pjlCopyrightAddAdminPage' );

?>
